==> lucide_py-0.1.0-py3-none-any.whl: lucide/icons/grip.py <==
from .. import IconBase


class IconGrip(IconBase):
    class_name = "lucide lucide-grip"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "viewBox": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "12",
                "cy": "5",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "5",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "5",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "12",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "12",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "12",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "19",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "19",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "19",
                "r": "1"
            }
        }
    ]
}

==> lucide_py-0.1.1-py3-none-any.whl: lucide/icons/grip.py <==
from .. import IconBase


class IconGrip(IconBase):
    class_name = "lucide lucide-grip"
    svg_data = {
    "attrs": {
        "width": "24",
        "height": "24",
        "view_box": "0 0 24 24",
        "fill": "none",
        "stroke": "currentColor",
        "stroke_width": "2",
        "stroke_linecap": "round",
        "stroke_linejoin": "round"
    },
    "items": [
        {
            "circle": {
                "cx": "12",
                "cy": "5",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "5",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "5",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "12",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "12",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "12",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "12",
                "cy": "19",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "19",
                "cy": "19",
                "r": "1"
            }
        },
        {
            "circle": {
                "cx": "5",
                "cy": "19",
                "r": "1"
            }
        }
    ]
}
